@@ -15,6 +15,7 @@ from packaging import version
 from .helpers import *
 from .utils import figure, ioff, nearest_idx
 from .controller import gogogo_controls
+from .xarray_helpers import get_hs_axes, get_hs_extent, get_hs_fmts
 
 # functions that are methods
 __all__ = [
@@ -578,7 +579,14 @@ def hyperslicer(
     controls
     """
 
-    arr = np.asarray(np.squeeze(arr))
+    arr = np.squeeze(arr)
+
+    arr_type = "numpy"
+    if "xarray.core.dataarray.DataArray" in str(arr.__class__):
+        arr_type = "xarray"
+    elif "dask.array.core.Array" in str(arr.__class__):
+        arr_type = "dask"
+
     if arr.ndim < 3 + is_color_image:
         raise ValueError(
             f"arr must be at least {3+is_color_image}D but it is {arr.ndim}D. mpl_interactions.imshow for 2D images."
@@ -599,11 +607,15 @@ def hyperslicer(
 
     names = None
     axes = None
-    if "names" in kwargs:
-        names = kwargs.pop("names")
+    if arr_type != "xarray":
+        if "names" in kwargs:
+            names = kwargs.pop("names")
 
-    elif "axes" in kwargs:
-        axes = kwargs.pop("axes")
+        elif "axes" in kwargs:
+            axes = kwargs.pop("axes")
+
+    else:
+        axes = get_hs_axes(arr, is_color_image=is_color_image)
 
     # Just pass in an array - no kwargs
     for i in range(arr.ndim - im_dims):
@@ -662,6 +674,13 @@ def hyperslicer(
             slider_format_strings[name] = "{:.0f}"
             kwargs[name] = np.arange(arr.shape[i])
 
+    if arr_type == "xarray":
+        slider_format_strings = get_hs_fmts(arr, is_color_image=is_color_image)
+        extent = get_hs_extent(arr, is_color_image=is_color_image)
+    else:
+        if "extent" not in kwargs:
+            extent = None
+
     controls, params = gogogo_controls(
         kwargs, controls, display_controls, slider_format_strings, play_buttons, allow_dupes=True
     )
