@@ -40,6 +40,7 @@ __all__ = [
     "gogogo_display",
     "create_mpl_controls_fig",
     "eval_xy",
+    "choose_fmt_str",
 ]
 
 
@@ -627,3 +628,31 @@ def gogogo_display(ipympl, use_ipywidgets, display, controls, fig):
             fig.show()
             controls[0].show()
     return controls
+
+
+def choose_fmt_str(dtype=None):
+    """
+    Choose the appropriate string formatting for different dtypes.
+
+    Paramters
+    ---------
+
+    dtype : np.dtye
+    dtype of array containing values to be formatted.
+
+    Returns
+    -------
+
+    fmt : str
+    Format string
+    """
+    if np.issubdtype(dtype, "float"):
+        fmt = r"{:0.2f}"
+
+    elif np.issubdtype(dtype, "int"):
+        fmt = r"{:d}"
+
+    else:
+        fmt = r"{:}"
+
+    return fmt
